@@ -18,6 +18,7 @@
 
 from __future__ import annotations
 
+import asyncio
 import typing as t
 
 
@@ -118,17 +119,25 @@ class GraphDatabase:
     else:
 
         @classmethod
-        def driver(cls, uri, *, auth=None, **config) -> Driver:
+        def driver(
+            cls, uri: str, *,
+            auth: t.Union[t.Tuple[t.Any, t.Any], Auth, None] = None,
+            **config
+        ) -> Driver:
             """Create a driver.
 
-            :param uri: the connection URI for the driver, see :ref:`uri-ref` for available URIs.
-            :param auth: the authentication details, see :ref:`auth-ref` for available authentication details.
-            :param config: driver configuration key-word arguments, see :ref:`driver-configuration-ref` for available key-word arguments.
+            :param uri: the connection URI for the driver,
+                see :ref:`uri-ref` for available URIs.
+            :param auth: the authentication details,
+                see :ref:`auth-ref` for available authentication details.
+            :param config: driver configuration key-word arguments,
+                see :ref:`driver-configuration-ref` for available
+                key-word arguments.
             """
 
             driver_type, security_type, parsed = parse_neo4j_uri(uri)
 
-            # TODO: 6.0 remove "trust" config option
+            # TODO: 6.0 - remove "trust" config option
             if "trust" in config.keys():
                 if config["trust"] not in (
                     TRUST_ALL_CERTIFICATES,
@@ -163,7 +172,7 @@ class GraphDatabase:
                      or "ssl_context" in config.keys())):
                 from ..exceptions import ConfigurationError
 
-                # TODO: 6.0 remove "trust" from error message
+                # TODO: 6.0 - remove "trust" from error message
                 raise ConfigurationError(
                     'The config settings "encrypted", "trust", '
                     '"trusted_certificates", and "ssl_context" can only be '
@@ -271,7 +280,7 @@ class GraphDatabase:
             Function which will be called whenever the set of bookmarks
             handled by the bookmark manager gets updated with the new
             internal bookmark set. It will receive the new set of bookmarks
-            as a :class:`.Bookmarks` object and return :const:`None`.
+            as a :class:`.Bookmarks` object and return :data:`None`.
 
         :returns: A default implementation of :class:`BookmarkManager`.
 
@@ -463,7 +472,11 @@ class Driver:
     def close(self) -> None:
         """ Shut down, closing any open connections in the pool.
         """
-        self._pool.close()
+        try:
+            self._pool.close()
+        except asyncio.CancelledError:
+            self._closed = True
+            raise
         self._closed = True
 
     if t.TYPE_CHECKING:
